@@ -1,6 +1,25 @@
 #!/bin/bash
+# Copyright (C) 2001,2002 by Stefano Falsetto
+# e-mail contact ....: mailto:stefko5@inwind.it
+#
+#    This program is free software; you can redistribute it and/or modify
+#    it under the terms of the GNU General Public License as published by
+#    the Free Software Foundation; either version 2 of the License, or
+#    (at your option) any later version.
+#
+#    This program is distributed in the hope that it will be useful,
+#    but WITHOUT ANY WARRANTY; without even the implied warranty of
+#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+#    GNU General Public License for more details.
+#
+#    You should have received a copy of the GNU General Public License
+#    along with this program; if not, write to the Free Software
+#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+#
+#
 
-echo "install script for Rot[t]Log v.$VERSION"
+source ./VERSION
+echo "Install script for Rot[t]Log v.$VERSION"
 echo
 
 echo -n "Checking for sed... "
@@ -23,12 +42,10 @@ if [ -z "$AWK" ]; then
 fi
 echo "Done"
 
-. ./VERSION
-
 source ./DefConf.inc
 
 DOCFILES="COPYING ChangeLog README INSTALL TODO sample_monthly sample_rc"
-MANFILES="rottlog.8 rottlogex.5"
+MANFILES="rottlog.8 rottlogconf.5 rottlogex.5"
 
 echo "Updating bash codes... "
 
